.. _contents:

NetworkX documentation
======================

.. htmlonly::

    :Release: |version|
    :Date: |today|

    Download `PDF <http://networkx.lanl.gov/networkx.pdf>`_
    `HTML <http://networkx.lanl.gov/networkx-documentation.zip>`_


.. toctree::
   :maxdepth: 2

   install
   tutorial/index
   reference/index
   download


.. htmlonly::
   - `Examples <examples/index.html>`_


.. htmlonly::
   - `Gallery <gallery/index.html>`_




   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

